#
# spec file for package breeze6-gtk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0

# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%define rname breeze-gtk

# Use the latest python on factory
%define pythons %{primary_python}
# Only defined for Leap 15
%{?sle15_python_module_pythons}

%bcond_without released
Name:           breeze6-gtk
Version:        6.3.3
Release:        1.0.2.1.sr20250302
Summary:        GTK+ theme matching KDE's Breeze
License:        LGPL-2.1-only
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  %{python_module pycairo}
BuildRequires:  breeze6-style >= %{_plasma6_bugfix}
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  sassc
BuildRequires:  cmake(Breeze) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6CoreTools)

%description
A GTK+ theme created to match with the Plasma 6 Breeze theme.

%package -n metatheme-breeze6-common
Summary:        GTK+ theme matching KDE's Breeze -- Common Files
# Default cursor theme
Recommends:     breeze6-cursors
Suggests:       gtk2-metatheme-breeze6
Suggests:       gtk3-metatheme-breeze6
Suggests:       gtk4-metatheme-breeze6
Provides:       metatheme-breeze-common = %{version}
Obsoletes:      metatheme-breeze-common < %{version}
Provides:       breeze-gtk = %{version}
Obsoletes:      breeze-gtk < %{version}

%description -n metatheme-breeze6-common
A GTK+ theme created to match with the Plasma 6 Breeze theme.

%package -n gtk2-metatheme-breeze6
Summary:        GTK+ theme matching KDE's Breeze -- GTK+ 2 Support
Requires:       metatheme-breeze6-common = %{version}
Supplements:    (breeze4-style and gtk2)
Supplements:    (breeze5-style and gtk2)
Supplements:    (breeze6-style and gtk2)
Provides:       gtk2-metatheme-breeze = %{version}
Obsoletes:      gtk2-metatheme-breeze < %{version}
BuildArch:      noarch

%description -n gtk2-metatheme-breeze6
A GTK+ theme created to match with the Plasma 6 Breeze theme.

%package -n gtk3-metatheme-breeze6
Summary:        GTK+ theme matching KDE's Breeze -- GTK+ 3 Support
Requires:       metatheme-breeze6-common = %{version}
Supplements:    (breeze4-style and gtk3)
Supplements:    (breeze5-style and gtk3)
Supplements:    (breeze6-style and gtk3)
Provides:       gtk3-metatheme-breeze = %{version}
Obsoletes:      gtk3-metatheme-breeze < %{version}
BuildArch:      noarch

%description -n gtk3-metatheme-breeze6
A GTK+ theme created to match with the Plasma 6 Breeze theme.

%package -n gtk4-metatheme-breeze6
Summary:        GTK+ theme matching KDE's Breeze -- GTK+ 4 Support
Requires:       metatheme-breeze6-common = %{version}
Supplements:    (breeze4-style and gtk4)
Supplements:    (breeze5-style and gtk4)
Supplements:    (breeze6-style and gtk4)
Provides:       gtk4-metatheme-breeze = %{version}
Obsoletes:      gtk4-metatheme-breeze < %{version}
BuildArch:      noarch

%description -n gtk4-metatheme-breeze6
A GTK+ theme created to match with the Plasma 6 Breeze theme.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}%{_kf6_sharedir}

%files -n metatheme-breeze6-common
%license LICENSES/*
%doc README.md
%{_datadir}/themes/Breeze*/
%exclude %{_datadir}/themes/Breeze*/gtk-*/
%dir %{_kf6_sharedir}/themes/Breeze*/assets/

%files -n gtk2-metatheme-breeze6
%{_datadir}/themes/Breeze*/gtk-2.0/

%files -n gtk3-metatheme-breeze6
%{_datadir}/themes/Breeze*/gtk-3.*/

%files -n gtk4-metatheme-breeze6
%{_datadir}/themes/Breeze*/gtk-4.*/

%changelog
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * checkbox: Apply indeterminate after checked
  * assets: Set width/height for window button icons
  * gtk4: Fix dropdown style
  * update version for new release
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * checkbox: Apply indeterminate after checked
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * scrollbar: Don't use negative margin to counteract border size
  * scrollbar: Split margin between scrollbar and trough
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Changes since 6.0.5:
  * ecm set to framewrosk 6.2
  * update version for new release
  * Change radius from 0.75 (3px) to 1.25 (5px)
  * Set radiobutton and checkbox use button bg color
  * fix ecm version number
  * gtk3,gtk4: Remove visible scrollbar trough (aka groove)
  * Use 0.2 instead of varied values for outline contrasts
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4.1:
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4.1
- Changes since 6.0.3:
  * fix ecm version
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * fix ecm version number
  * update version for new release
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * fix ecm dep version
  * update version for new release
  * bump version ahead of next release
  * respin 6.0.1 tar
  * Don't require a non-existent ECM version
  * update version for new release
- Drop patches, now upstream:
  * 0001-Don-t-require-a-non-existent-ECM-version.patch
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
- Add patch to fix build:
  * 0001-Don-t-require-a-non-existent-ECM-version.patch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * Use 0.2 instead of varied values for outline contrasts
  * update version for new release
* Sun Feb 18 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- No code changes since 5.93.0
* Thu Feb 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Fix obsoleted versions
* Sat Jul 15 2023 Christophe Marin <christophe@krop.fr>
- Init breeze6-gtk
